<?php
/**
 * Plugin Name: myglobalHOST PHP Upload Limit Increaser
 * Plugin URI:  https://www.myglobalhost.in/
 * Description: Automatically increases the PHP upload and post upload limits to 100MB in the .htaccess file upon plugin activation.
 * Version:     1.0.0
 * Author:      myglobalHOST
 * Author URI:  https://www.myglobalhost.net/
 * License:     GPL2
 */

function increase_php_upload_limits() {
    $htaccess_file = ABSPATH . '.htaccess';

    if ( file_exists( $htaccess_file ) && is_writable( $htaccess_file ) ) {
        $htaccess_content = file_get_contents( $htaccess_file );

        // Lines to be added to .htaccess
        $new_lines = [
            'php_value upload_max_filesize 100M',
            'php_value post_max_size 100M',
        ];

        // Check if lines already exist to avoid duplicates
        $lines_exist = true;
        foreach ( $new_lines as $line ) {
            if ( strpos( $htaccess_content, $line ) === false ) {
                $lines_exist = false;
                break;
            }
        }

        if ( ! $lines_exist ) {
            $new_content = implode( "\n", $new_lines ) . "\n" . $htaccess_content;
            file_put_contents( $htaccess_file, $new_content );
        }
    } else {
        error_log( 'PHP Upload Limit Increaser: .htaccess file not found or not writable.' );
        // Or, you could display an admin notice here
    }
}

register_activation_hook( __FILE__, 'increase_php_upload_limits' );
